==> eam-wshub-proxyclient-11.5-10-sources.jar: net/datastream/schemas/mp_fields/CONDITIONSCOREMATRIXSETUPID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour CONDITIONSCOREMATRIXSETUPID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="CONDITIONSCOREMATRIXSETUPID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CONDITIONSCOREMATRIXSETUPPK"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CONDITIONSCOREMATRIXSETUPID_Type", propOrder = {
    "conditionscorematrixsetuppk"
})
public class CONDITIONSCOREMATRIXSETUPID_Type {

    @XmlElement(name = "CONDITIONSCOREMATRIXSETUPPK", required = true)
    protected QUANTITY conditionscorematrixsetuppk;

    /**
     * Obtient la valeur de la propriété conditionscorematrixsetuppk.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getCONDITIONSCOREMATRIXSETUPPK() {
        return conditionscorematrixsetuppk;
    }

    /**
     * Définit la valeur de la propriété conditionscorematrixsetuppk.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setCONDITIONSCOREMATRIXSETUPPK(QUANTITY value) {
        this.conditionscorematrixsetuppk = value;
    }

}

==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_fields/CONDITIONSCOREMATRIXSETUPID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for CONDITIONSCOREMATRIXSETUPID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CONDITIONSCOREMATRIXSETUPID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CONDITIONSCOREMATRIXSETUPPK"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CONDITIONSCOREMATRIXSETUPID_Type", propOrder = {
    "conditionscorematrixsetuppk"
})
public class CONDITIONSCOREMATRIXSETUPID_Type {

    @XmlElement(name = "CONDITIONSCOREMATRIXSETUPPK", required = true)
    protected QUANTITY conditionscorematrixsetuppk;

    /**
     * Gets the value of the conditionscorematrixsetuppk property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getCONDITIONSCOREMATRIXSETUPPK() {
        return conditionscorematrixsetuppk;
    }

    /**
     * Sets the value of the conditionscorematrixsetuppk property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setCONDITIONSCOREMATRIXSETUPPK(QUANTITY value) {
        this.conditionscorematrixsetuppk = value;
    }

}
